===============================
iziconf
===============================


.. image:: https://img.shields.io/pypi/v/iziconf.svg
        :target: https://pypi.python.org/pypi/iziconf

.. image:: https://img.shields.io/travis/ant31/iziconf.svg
        :target: https://travis-ci.org/ant31/iziconf

.. image:: https://pyup.io/repos/github/ant31/iziconf/shield.svg
     :target: https://pyup.io/repos/github/ant31/iziconf/
     :alt: Updates


short description
Features
--------

* TODO
